Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Kunal Joshi <kunal1.joshi@intel.com>
To: igt-dev@lists.freedesktop.org
Cc: Kunal Joshi <kunal1.joshi@intel.com>
Subject: [PATCH i-g-t 2/2] lib/igt_kms: add support for choosing big joiner mode
Date: Thu, 18 Jan 2024 16:16:16 +0530	[thread overview]
Message-ID: <20240118104616.988247-3-kunal1.joshi@intel.com> (raw)
In-Reply-To: <20240118104616.988247-1-kunal1.joshi@intel.com>

add support to choose big joiner mode with environment
variable, use mode with highest clock if no mode with big joiner
found.

v2: reuse bigjoiner_mode_found (Bhanu)
v3: avoid returning from multiple places (Bhanu)
    avoid frequent debugfs reads (Bhanu)
v4: use default mode (Bhanu)

Cc: Swati Sharma <swati2.sharma@intel.com>
Cc: Karthik B S <karthik.b.s@intel.com>
Cc: Bhanuprakash Modem <bhanuprakash.modem@intel.com>
Signed-off-by: Kunal Joshi <kunal1.joshi@intel.com>
---
 lib/igt_kms.c | 16 +++++++++++++---
 1 file changed, 13 insertions(+), 3 deletions(-)

diff --git a/lib/igt_kms.c b/lib/igt_kms.c
index 7a07e62f8..77059dd34 100644
--- a/lib/igt_kms.c
+++ b/lib/igt_kms.c
@@ -1771,8 +1771,9 @@ void igt_sort_connector_modes(drmModeConnector *connector,
 bool kmstest_get_connector_default_mode(int drm_fd, drmModeConnector *connector,
 					drmModeModeInfo *mode)
 {
+	bool found;
 	char *env;
-	int i;
+	int i, max_dotclock;
 
 	if (!connector->count_modes) {
 		igt_warn("no modes for connector %d\n",
@@ -1781,14 +1782,23 @@ bool kmstest_get_connector_default_mode(int drm_fd, drmModeConnector *connector,
 	}
 
 	env = getenv("IGT_KMS_RESOLUTION");
+	max_dotclock = igt_get_max_dotclock(drm_fd);
 	if (env) {
 		/*
 		 * Only (0 or 1) and (lowest or highest) are allowed.
 		 *
 		 * 0/lowest: Choose connector mode with lowest possible resolution.
 		 * 1/highest: Choose connector mode with highest possible resolution.
+		 * 2/joiner: Choose connector mode with bigjoiner support or default
+		 *	     mode if can't support  big joiner
 		 */
-		if (!strcmp(env, "highest") || !strcmp(env, "1"))
+		if (!strcmp(env, "joiner") || !strcmp(env, "2")) {
+			found = bigjoiner_mode_found(drm_fd, connector,
+						     max_dotclock);
+			if (!found)
+				goto default_mode;
+		}
+		else if (!strcmp(env, "highest") || !strcmp(env, "1"))
 			igt_sort_connector_modes(connector, sort_drm_modes_by_res_dsc);
 		else if (!strcmp(env, "lowest") || !strcmp(env, "0"))
 			igt_sort_connector_modes(connector, sort_drm_modes_by_res_asc);
@@ -1781,14 +1782,23 @@ bool kmstest_get_connector_default_mode(int drm_fd, drmModeConnector *connector,
 	if (env) {
 		/*
-		 * Only (0 or 1) and (lowest or highest) are allowed.
+		 * Only (0 or 1 or 2) and (lowest or highest or joiner) are allowed.
 		 *
 		 * 0/lowest: Choose connector mode with lowest possible resolution.
-- 
2.25.1


  parent reply	other threads:[~2024-01-18 10:36 UTC|newest]

Thread overview: 21+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-01-18 10:46 [PATCH i-g-t 0/2] add support for choosing big joiner mode Kunal Joshi
2024-01-18 10:46 ` [PATCH i-g-t 1/2] lib/igt_kms: move bigjoiner_mode_found to lib Kunal Joshi
2024-01-18 10:46 ` Kunal Joshi [this message]
2024-01-18 14:28 ` ✓ CI.xeBAT: success for add support for choosing big joiner mode (rev3) Patchwork
2024-01-18 14:39 ` ✓ Fi.CI.BAT: " Patchwork
2024-01-18 17:00 ` ✗ Fi.CI.IGT: failure " Patchwork
  -- strict thread matches above, loose matches on Subject: below --
2024-01-15 10:58 [PATCH i-g-t 0/2] add support for choosing big joiner mode Kunal Joshi
2024-01-15 10:58 ` [PATCH i-g-t 2/2] lib/igt_kms: " Kunal Joshi
2024-01-16 11:04   ` Sharma, Swati2
2024-01-16 11:59     ` Joshi, Kunal1
2024-01-16 11:59       ` Joshi, Kunal1
2024-01-16 12:03       ` Sharma, Swati2
2024-01-17  5:44         ` Joshi, Kunal1
2024-01-17  5:44           ` Joshi, Kunal1
2024-01-17  8:55           ` Sharma, Swati2
2024-01-17  9:14             ` Joshi, Kunal1
2024-01-18  9:10               ` Modem, Bhanuprakash
2024-01-18  9:14                 ` Joshi, Kunal1
2024-01-18 10:38                   ` Nautiyal, Ankit K
2024-01-18 11:28                     ` Joshi, Kunal1
2024-01-18 14:15                 ` Sharma, Swati2
2024-01-12  8:55 [PATCH i-g-t 0/2] " Kunal Joshi
2024-01-12  8:55 ` [PATCH i-g-t 2/2] lib/igt_kms: " Kunal Joshi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240118104616.988247-3-kunal1.joshi@intel.com \
    --to=kunal1.joshi@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox